@@ -3,14 +3,19 @@ import warnings
 
 import pandas as pd
 
-from econuy.utils.lstrings import urls
+from econuy.utils.sources import urls
 
 
 def _set(
-        df: pd.DataFrame, area: Optional[str] = None,
-        currency: Optional[str] = None, inf_adj: Optional[str] = None,
-        unit: Optional[str] = None, seas_adj: Optional[str] = None,
-        ts_type: Optional[str] = None, cumperiods: Optional[int] = None
+    df: pd.DataFrame,
+    area: Optional[str] = None,
+    currency: Optional[str] = None,
+    inf_adj: Optional[str] = None,
+    unit: Optional[str] = None,
+    seas_adj: Optional[str] = None,
+    ts_type: Optional[str] = None,
+    cumperiods: Optional[int] = None,
+    warn: bool = False,
 ):
     """Add a multiindex to a dataframe's columns.
 
@@ -34,6 +39,8 @@ def _set(
         Time series type, generally 'Stock' or 'Flujo'.
     cumperiods : int or None (default is None)
         Number of periods accumulated per period.
+    warn : bool, default False
+        If False, don't raise warnings.
 
     Returns
     -------
@@ -48,24 +55,44 @@ def _set(
     try:
         inferred_freq = pd.infer_freq(df.index)
     except ValueError:
-        warnings.warn("ValueError: Need at least 3 dates to infer frequency. "
-                      "Setting to '-'.", UserWarning)
+        if warn:
+            warnings.warn(
+                "ValueError: Need at least 3 dates to infer frequency. " "Setting to '-'.",
+                UserWarning,
+            )
         inferred_freq = "-"
     if inferred_freq is None:
-        warnings.warn("Metadata: frequency could not be inferred "
-                      "from the index. Setting to '-'.", UserWarning)
+        if warn:
+            warnings.warn(
+                "Metadata: frequency could not be inferred " "from the index. Setting to '-'.",
+                UserWarning,
+            )
         inferred_freq = "-"
     names = [
-        "Indicador", "Área", "Frecuencia", "Moneda",
-        "Inf. adj.", "Unidad", "Seas. Adj.", "Tipo", "Acum. períodos"
+        "Indicador",
+        "Área",
+        "Frecuencia",
+        "Moneda",
+        "Inf. adj.",
+        "Unidad",
+        "Seas. Adj.",
+        "Tipo",
+        "Acum. períodos",
     ]
     if not isinstance(df.columns, pd.MultiIndex):
         df.columns = pd.MultiIndex.from_product(
             [
-                colnames, [area], [inferred_freq], [currency], [inf_adj],
-                [unit], [seas_adj], [ts_type], [cumperiods]
+                colnames,
+                [area],
+                [inferred_freq],
+                [currency],
+                [inf_adj],
+                [unit],
+                [seas_adj],
+                [ts_type],
+                [cumperiods],
             ],
-            names=names
+            names=names,
         )
     else:
         arrays = []
@@ -98,34 +125,34 @@ def _set(
         return
 
 
-def _modify_multiindex(df: pd.DataFrame, levels: List[int],
-                       new_arrays: List[List[str]]):
+def _modify_multiindex(df: pd.DataFrame, levels: List[int], new_arrays: List[List[str]]):
     arrays = []
     for level in range(0, 9):
         arrays.append(list(df.columns.get_level_values(level)))
     for level, new_array in zip(levels, new_arrays):
         arrays[level] = new_array
     tuples = list(zip(*arrays))
-    df.columns = pd.MultiIndex.from_tuples(tuples,
-                                           names=["Indicador", "Área",
-                                                  "Frecuencia", "Moneda",
-                                                  "Inf. adj.", "Unidad",
-                                                  "Seas. Adj.", "Tipo",
-                                                  "Acum. períodos"])
+    df.columns = pd.MultiIndex.from_tuples(
+        tuples,
+        names=[
+            "Indicador",
+            "Área",
+            "Frecuencia",
+            "Moneda",
+            "Inf. adj.",
+            "Unidad",
+            "Seas. Adj.",
+            "Tipo",
+            "Acum. períodos",
+        ],
+    )
     return
 
 
-def _get_sources(dataset: str,
-                 html_urls: bool = True) -> Tuple[List[Optional[str]],
-                                                  List[str], List[str]]:
+def _get_sources(
+    dataset: str, html_urls: bool = True
+) -> Tuple[List[Optional[str]], List[str], List[str]]:
     """Given a dataset name, return source URLs and provider."""
-    if dataset.startswith("balance_fss"):
-        dataset = "balance_fss"
-    elif dataset.startswith("balance"):
-        dataset = "balance"
-    elif dataset.startswith("public_debt"):
-        dataset = "public_debt"
-
     direct = urls[dataset]["source"]["direct"]
     indirect = urls[dataset]["source"]["indirect"]
     provider = urls[dataset]["source"]["provider"]
